package dateselector;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Map;

import javax.faces.component.EditableValueHolder;
import javax.faces.component.UIComponent;
import javax.faces.component.ValueHolder;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.faces.convert.Converter;
import javax.faces.render.Renderer;
public class DateSelectorRenderer extends Renderer {
  public void encodeBegin(FacesContext context, UIComponent component) throws IOException {
    if (!component.isRendered()) {
      return;
    }
    Date from = null;
    Object value = component.getAttributes().get("from");
    if (value instanceof Date) {
      from = (Date) value;
    } else {
      from = new Date();
    }
        
    int days = 7;
    value = component.getAttributes().get("days");
    if (value instanceof Integer) {
      days = ((Integer) value).intValue();
    } else {
      try {
        days = Integer.parseInt((String) value);
      } catch (NumberFormatException e) {}
    }
    
    ResponseWriter writer = context.getResponseWriter();
    String clientId = component.getClientId(context);
    writer.startElement("select", component);
    writer.writeAttribute("name", clientId, "id");
    Calendar next = new GregorianCalendar();
    SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
    next.setTime(from);
    for (int i = 0; i < days; i++) {
      writer.startElement("option", component);
      writer.writeAttribute("value", String.valueOf(next.getTimeInMillis()), null);
      writer.write(sdf.format(next.getTime()));
      next.add(Calendar.DATE, 1);
    }
    writer.endElement("select");
  }

  public void decode(FacesContext context, UIComponent component) {
    Map parameters = context.getExternalContext().getRequestParameterMap();
    String clientId = component.getClientId(context);
    String value = (String) parameters.get(clientId);
    if (value != null) {
      ((EditableValueHolder) component).setSubmittedValue(value);
    }
  }

  public Object getConvertedValue(FacesContext context, UIComponent component, Object value) {
    Converter converter = ((ValueHolder) component).getConverter();
    Object convertedValue;
    if (converter != null) {
      convertedValue = converter.getAsObject(context, component, (String) value);
    } else {
      long millis = Long.parseLong((String) value);
      convertedValue = new Date(millis);
    }
    return convertedValue;
  }

}
