package dateselector;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Map;

import javax.faces.component.EditableValueHolder;
import javax.faces.component.UIComponent;
import javax.faces.component.UIForm;
import javax.faces.component.ValueHolder;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.faces.convert.Converter;
import javax.faces.render.Renderer;
public class DateSelectorRenderer extends Renderer {
  private static final String PREV_ID = "prev";
  private static final String NEXT_ID = "next";
  public void encodeBegin(FacesContext context, UIComponent component) throws IOException {
    if (!component.isRendered()) {
      return;
    }

    Date from = null;
    Object value = component.getAttributes().get("from");
    if (value instanceof Date) {
      from = (Date) value;
    } else {
      from = new Date();
    }
    ((DateSelector) component).initDate(from);
    
    ResponseWriter writer = context.getResponseWriter();
    String clientId = component.getClientId(context);

    String prevCommand = clientId + UIForm.SEPARATOR_CHAR + PREV_ID;
    writeCommandButton(writer, component, prevCommand, "O");

    writer.startElement("select", component);
    writer.writeAttribute("name", clientId, "id");
    Date date = ((DateSelector) component).getDate();
    GregorianCalendar next = new GregorianCalendar();
    next.setTime(date);
    SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
    next.set(Calendar.DAY_OF_MONTH, 1);
    int month = next.get(Calendar.MONTH);
    while (true) {
      writer.startElement("option", component);
      writer.writeAttribute("value", String.valueOf(next.getTimeInMillis()), null);
      writer.write(sdf.format(next.getTime()));
      next.add(Calendar.DATE, 1);
      if (next.get(Calendar.MONTH) != month) {
        break;
      }
    }
    writer.endElement("select");

    String nextCommand = clientId + UIForm.SEPARATOR_CHAR + NEXT_ID;
    writeCommandButton(writer, component, nextCommand, "");
  }
  private void writeCommandButton(ResponseWriter writer, UIComponent component, String command, String value) throws IOException {
    writer.startElement("input", component);
    writer.writeAttribute("type", "submit" , null);
    writer.writeAttribute("name", command, null);
    writer.writeAttribute("value", value, null);
  }

  public void decode(FacesContext context, UIComponent component) {
    Map parameters = context.getExternalContext().getRequestParameterMap();
    String clientId = component.getClientId(context);
    String value = (String) parameters.get(clientId);
    if (value != null) {
      ((EditableValueHolder) component).setSubmittedValue(value);
    }
    
    if (parameters.get(clientId + UIForm.SEPARATOR_CHAR + PREV_ID) != null) {
      ((DateSelector) component).navigatePrevious();
      context.renderResponse();
    }
    if (parameters.get(clientId + UIForm.SEPARATOR_CHAR + NEXT_ID) != null) {
      ((DateSelector) component).navigateNext();
      context.renderResponse();
    }
    
  }

  public Object getConvertedValue(FacesContext context, UIComponent component, Object value) {
    Converter converter = ((ValueHolder) component).getConverter();
    Object convertedValue;
    if (converter != null) {
      convertedValue = converter.getAsObject(context, component, (String) value);
    } else {
      long millis = Long.parseLong((String) value);
      convertedValue = new Date(millis);
    }
    return convertedValue;
  }

}
